<p class="logo">
  <a href="{{ pathto(master_doc) }}">
    <img class="logo" src="{{ pathto('_static/equation.png', 1) }}" title="Tartaruga Feliz Equation"/>
  </a>
</p>
<p>

<p>
<a href="http://libcrush.org/main/python-crush.git">crush</a>
library to control placement in a hierarchy.
</p>
